package com.syc.slm.slmbi.controller;

import com.syc.slm.common.core.util.R;
import com.syc.slm.slmbi.dto.InstrumentPanelConfigDTO;
import com.syc.slm.slmbi.dto.InstrumentPanelPermissionDTO;
import com.syc.slm.slmbi.service.InstrumentPanelConfigService;
import com.syc.slm.slmbi.vo.InstrumentPanelConfigVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * slm-bi
 * 仪表板样式以及数据配置
 *
 * @author : lin
 * @date : 2021-03-25 19:09
 **/

@RequestMapping("/panel/configs")
@RestController
@Api(value = "仪表板样式以及数据配置", description = "仪表板样式以及数据配置")
public class InstrumentPanelConfigController {

    @Autowired
    private InstrumentPanelConfigService instrumentPanelConfigService;

    @PostMapping
    @ApiOperation("保存仪表板样式以及数据配置")
    @ApiImplicitParams({@ApiImplicitParam(name = "instrumentPanelId", value = "仪表板id", required = true),
        @ApiImplicitParam(name = "visitPermission",
            value = "访问权限",
            required = true,
            dataTypeClass = InstrumentPanelPermissionDTO.class),
        @ApiImplicitParam(name = "configDetails", value = "仪表板配置详情", required = true)})
    public R<Boolean> saveInstrumentPanelConfig(@RequestBody InstrumentPanelConfigDTO config) {
        return R.ok(instrumentPanelConfigService.saveInstrumentPanelConfig(config, 1));
    }

    @PostMapping("save-push")
    @ApiOperation("保存发布仪表板样式以及数据配置")
    @ApiImplicitParams({@ApiImplicitParam(name = "instrumentPanelId", value = "仪表板id", required = true),
        @ApiImplicitParam(name = "visitPermission",
            value = "访问权限",
            required = true,
            dataTypeClass = InstrumentPanelPermissionDTO.class),
        @ApiImplicitParam(name = "configDetails", value = "仪表板配置详情", required = true)})
    public R<Boolean> saveAndPushConfig(@RequestBody InstrumentPanelConfigDTO config) {
        return R.ok(instrumentPanelConfigService.saveInstrumentPanelConfig(config, 2));
    }

    @GetMapping("{panelId}")
    @ApiOperation("根据仪表板id获取仪表板配置")
    @ApiImplicitParam(name = "instrumentPanelId", value = "仪表板id")
    public R<InstrumentPanelConfigVo> getInstrumentPanelConfigByInstrumentPanelId(
        @PathVariable("panelId") String panelId) {
        return R.ok(instrumentPanelConfigService.getInstrumentPanelConfigByInstrumentPanelId(panelId));
    }

}
