package com.syc.slm.slmbi.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.syc.slm.common.core.util.R;
import com.syc.slm.slmbi.dto.InstrumentPanelDTO;
import com.syc.slm.slmbi.entity.InstrumentPanel;
import com.syc.slm.slmbi.service.InstrumentPanelService;
import com.syc.slm.slmbi.vo.InstrumentPanelVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * slm-bi
 * 仪表板
 *
 * @author : lin
 * @date : 2021-03-25 15:10
 **/
@RestController
@RequestMapping("/panels")
@Api(value = "仪表板", description = "仪表板配置接口")
public class InstrumentPanelController {

    @Autowired
    private InstrumentPanelService instrumentPanelService;

    @GetMapping
    @ApiOperation("仪表板列表")
    public R<IPage<InstrumentPanelVo>> selectInstrumentPanelList(@RequestBody
        InstrumentPanelDTO where) {  //where :{name:'',creator:'',updater:'',startDate:'' ,endDate:'',recordStatus:''}
        return R.ok(instrumentPanelService.selectInstrumentPanelList(where));
    }

    @PostMapping
    @ApiOperation("新增仪表板")
    public R<Boolean> saveInstrumentPanel(@RequestBody InstrumentPanel panel) {
        return R.ok(instrumentPanelService.saveInstrumentPanel(panel));
    }

    @PutMapping("/batch-push")
    @ApiOperation("批量发布")
    @ApiImplicitParam(name = "ids", value = "仪表板id集合", required = true)
    public R<Boolean> batchPush(@RequestBody List<String> ids) {
        return R.ok(instrumentPanelService.batchPushInstrumentPanel(ids, 1));
    }

    @PutMapping("/offline/{id}")
    @ApiOperation("下线")
    @ApiImplicitParam(name = "id", value = "仪表板id", required = true)
    public R<Boolean> offline(@PathVariable("id") String id) {
        return R.ok(instrumentPanelService.offline(id));
    }

    @DeleteMapping("/{id}")
    @ApiOperation("删除仪表板")
    @ApiImplicitParam(name = "id", value = "仪表板id", required = true)
    public R<Boolean> delPushInstrumentPanel(@PathVariable("id") String id) {
        return R.ok(instrumentPanelService.delPushInstrumentPanel(id));
    }

    @PostMapping("/save-as")
    @ApiOperation("另存为")
    public R<Boolean> saveAs(@RequestBody InstrumentPanelDTO instrumentPanelDTO) {
        return R.ok(instrumentPanelService.saveInstrumentPanel(instrumentPanelDTO));
    }

    @PostMapping("/show-recovery-btn/{id}")
    @ApiOperation("是否显示恢复按钮")
    @ApiImplicitParam(name = "id", value = "仪表板id", required = true)
    public R<Boolean> showRecoveryBtn(@PathVariable("id") String id) {
        return R.ok(instrumentPanelService.showRecoveryBtn(id));
    }

    @PutMapping("/recovery/{id}")
    @ApiOperation("恢复按钮操作")
    @ApiImplicitParam(name = "id", value = "仪表板id", required = true)
    public R<Boolean> recoveryInstrumentPanel(@PathVariable("id") String id) {
        return R.ok(instrumentPanelService.recoveryInstrumentPanel(id));
    }

}
