package com.syc.slm.slmbi.controller;

import com.syc.slm.common.core.util.R;
import com.syc.slm.slmbi.dto.InstrumentPanelGroupDTO;
import com.syc.slm.slmbi.entity.InstrumentPanelGroup;
import com.syc.slm.slmbi.service.InstrumentPanelGroupService;
import com.syc.slm.slmbi.vo.InstrumentPanelGroupVo;
import com.syc.slm.slmbi.vo.PanelGroupVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * slm-bi
 * 仪表板分组
 *
 * @author : lin
 * @date : 2021-03-25 15:07
 **/
@RestController
@RequestMapping("/panel/groups")
@Api(value = "仪表板分组")
public class InstrumentPanelGroupController {

    @Autowired
    private InstrumentPanelGroupService instrumentPanelGroupService;

    @GetMapping
    @ApiOperation("第一次进入页面,或者点击查询，获取全部分组下的仪表板数据，以及分组数据")
    @ApiImplicitParam(name = "name", value = "分组名称或者仪表板名称")
    public R<List<PanelGroupVo>> selectInstrumentPanelGroupList(
        @RequestParam(value = "name", required = false) String name) {
        return R.ok(instrumentPanelGroupService.loadTrees(name));
    }

    @GetMapping("/next-nodes")
    @ApiOperation("点击节点获取，该分组下的仪表板信息，以及分组数据")
    @ApiImplicitParams({@ApiImplicitParam(name = "groupId", value = "分组id", required = true),
        @ApiImplicitParam(name = "name", value = "分组名称或者仪表板名称")})
    public R<List<PanelGroupVo>> findNextNodes(@RequestParam("groupId") String groupId,
        @RequestParam(value = "name", required = false) String name) {
        return R.ok(instrumentPanelGroupService.findNextNodes(groupId, name));
    }

    @GetMapping("/selectInstrumentPanelGroups")
    @ApiOperation("获取所有的仪表板分组以及分组下的仪表板以及仪表板下的组件")
    public R<List<InstrumentPanelGroupVo>> selectInstrumentPanelGroups() {
        return R.ok(instrumentPanelGroupService.selectInstrumentPanelGroupList());
    }

    @PostMapping
    @ApiOperation("保存仪表板分组")
    public R<Boolean> saveInstrumentPanelGroup(@RequestBody InstrumentPanelGroupDTO group) {
        return R.ok(instrumentPanelGroupService.saveInstrumentPanelGroup(group));
    }

    @PutMapping
    @ApiOperation("更新仪表板分组")
    public R<Boolean> updateInstrumentPanelGroup(@RequestBody InstrumentPanelGroupDTO group) {
        return R.ok(instrumentPanelGroupService.updateInstrumentPanelGroup(group));
    }

    @DeleteMapping("/{groupId}")
    @ApiOperation("删除仪表板分组")
    public R<Boolean> delInstrumentPanelGroup(@PathVariable String groupId) {
        return R.ok(instrumentPanelGroupService.delInstrumentPanelGroup(groupId));
    }

}
