package com.syc.slm.slmbi.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.syc.slm.common.core.util.R;
import com.syc.slm.slmbi.dto.VariableDTO;
import com.syc.slm.slmbi.service.VariableService;
import com.syc.slm.slmbi.vo.VariableDeviceVo;
import com.syc.slm.slmbi.vo.VariableSourceVo;
import com.syc.slm.slmbi.vo.VariableVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * slm-bi
 * 用户信息
 *
 * @author : lin
 * @date : 2021-03-25 18:45
 **/
@RestController
@RequestMapping("/variables")
@Api(description = "变量控件")
public class VariableController {
    @Autowired
    private VariableService variableService;

    @GetMapping
    @ApiOperation("获取变量列表")
    @ApiImplicitParams({@ApiImplicitParam(name = "sourceId", value = "变量来源"),
        @ApiImplicitParam(name = "deviceId", value = "所属设备"),
        @ApiImplicitParam(name = "variableName", value = "变量名称"),
        @ApiImplicitParam(name = "description", value = "描述")})
    public R<IPage<VariableVo>> getVariableList(@RequestBody VariableDTO variableDTO) {
        return R.ok(variableService.getVariableList(variableDTO));
    }

    @GetMapping("real-time")
    @ApiOperation("获取变量实时数据")
    @ApiImplicitParams({@ApiImplicitParam(name = "variableIds", value = "变量集合ids", required = true),
        @ApiImplicitParam(name = "format", value = "时间格式", required = true),
        @ApiImplicitParam(name = "interval", value = "时间间隔,代表(天，时，分，秒)", required = true),
        @ApiImplicitParam(name = "deviceId", value = "所属设备", required = true)})
    public R getVariableRealTimeDataList(@RequestBody VariableDTO variableDTO) {
        return R.ok();
    }

    @GetMapping("source")
    @ApiOperation("获取变量来源列表")
    public R<List<VariableSourceVo>> getVariableSourceList() {
        return R.ok(variableService.getVariableSourceList());
    }

    @GetMapping("device")
    @ApiOperation("获取变量所属设备列表")
    public R<List<VariableDeviceVo>> getVariableDeviceList() {
        return R.ok(variableService.getVariableDeviceList());
    }

    @GetMapping("history")
    @ApiOperation("获取变量历史数据")
    @ApiImplicitParams({@ApiImplicitParam(name = "variableIds", value = "变量集合ids", required = true),
        @ApiImplicitParam(name = "deviceId", value = "所属设备", required = true),
        @ApiImplicitParam(name = "statisticsType", value = "统计类型,代表(合计值，平均值，最大值，最小值)", required = true),
        @ApiImplicitParam(name = "startTime", value = "开始时间", required = true),
        @ApiImplicitParam(name = "endTime", value = "结束时间", required = true)})
    public R getVariableHistoryDataList(@RequestBody VariableDTO variableDTO) {
        return R.ok();
    }
}
